from sqlalchemy import  Column, Integer, String,DateTime, func, ForeignKey
from sqlalchemy.orm import relationship
from app import db
from sqlalchemy.ext.declarative import declarative_base
from datetime import datetime
import pytz

Base: declarative_base = db.Model

local_timezone = pytz.timezone("America/Los_Angeles")

def current_time():
    return datetime.now(local_timezone)
class AdvFrameType(Base):
    __tablename__ = "adv_frame_type"
    adv_frame_type_id = Column(Integer, primary_key=True)
    device_id = Column(Integer, ForeignKey('devices.device_id'), nullable=False)
    call_action = Column(String, nullable=True)
    count = Column(Integer, nullable=True)
    notify = Column(Integer, default=1)
    dt_mac = Column(String, nullable=True)
    flag = Column(Integer, default=0)
    created_at = Column(DateTime(timezone=True), default=current_time)
    updated_at = Column(DateTime(timezone=True), default=current_time, onupdate=current_time)

    device = relationship("Device", back_populates="adv_frame_types")
class Logs(Base):
    __tablename__ = "logs"
    alert_id = Column(Integer, primary_key=True)
    notify_text = Column(String, nullable=True)
    is_alert = Column(Integer, default=1)
    created_at = Column(DateTime(timezone=True), default=current_time)
    updated_at = Column(DateTime(timezone=True), default=current_time, onupdate=current_time)

class Alert_logs(Base):
    __tablename__= "alert_logs"
    id = Column(Integer, primary_key=True)
    patient_id = Column(Integer, nullable=False)
    alert_id = Column(Integer, nullable=False)
    zone_id = Column(Integer, nullable=False)
    site_id = Column(Integer, ForeignKey('sites.site_id'), nullable=True)
    room_id = Column(Integer, ForeignKey('rooms.id'), nullable=False)
    user_id =Column(Integer, nullable=False)
    note = Column(String, nullable=True)
    alert_type = Column(String, nullable=True)
    flag = Column(Integer, nullable=False)
    patient_or_staff_id = Column(Integer, nullable=False)
    created_at = Column(DateTime(timezone=True), default=current_time)
    updated_at = Column(DateTime(timezone=True), default=current_time, onupdate=current_time)

    site = relationship("Site", back_populates="alert_log")
    room = relationship("Room", back_populates="alert_log")
class LogsTimeline(Base):
    __tablename__= "logs_timeline"
    id = Column(Integer, primary_key=True)
    alert_id = Column(Integer, nullable=False)
    user_name = Column(Integer, ForeignKey('users.id'), nullable=True)
    status = Column(String, nullable=True)
    note = Column(String, nullable=True)
    alert_type = Column(String, nullable=True)
    created_at = Column(DateTime(timezone=True), default=current_time)
    updated_at = Column(DateTime(timezone=True), default=current_time, onupdate=current_time)

    user = relationship("User", back_populates="logs_timelines")

class AlertLogsHistory(Base):
    __tablename__= "alert_log_history"
    id = Column(Integer, primary_key=True)
    alert_id = Column(Integer, nullable=True)
    site_id = Column(Integer, nullable=True)
    zone_id = Column(Integer, nullable=True)
    patient_id = Column(Integer, nullable=True)
    alert_logg_array = Column(String, nullable=True)
    flag = Column(Integer, nullable=True)
    note = Column(String, nullable=True)
    patient_or_staff_id = Column(Integer, nullable=True)
    user_id = Column(Integer, nullable=True)
    created_at = Column(DateTime(timezone=True), default=current_time)
    updated_at = Column(DateTime(timezone=True), default=current_time, onupdate=current_time)

class AlertHistory(Base):
    __tablename__= "alert_logs_history"
    id = Column(Integer, primary_key=True)
    alert_id = Column(Integer, nullable=True)
    site_id = Column(Integer, nullable=True)
    zone_id = Column(Integer, nullable=True)
    alert_log_array = Column(String, nullable=True)
    alert_log_timeline = Column(String, nullable=True)
    patient_or_staff_id = Column(Integer, nullable=True)
    user_id = Column(Integer, nullable=True)
    created_at = Column(DateTime(timezone=True), default=current_time)
    updated_at = Column(DateTime(timezone=True), default=current_time, onupdate=current_time)